pymcr package
=============

Subpackages
-----------

.. toctree::

    pymcr.tests

Submodules
----------

pymcr.condition module
----------------------

.. automodule:: pymcr.condition
    :members:
    :undoc-members:
    :show-inheritance:

pymcr.constraints module
------------------------

.. automodule:: pymcr.constraints
    :members:
    :undoc-members:
    :show-inheritance:

pymcr.mcr module
----------------

.. automodule:: pymcr.mcr
    :members:
    :undoc-members:
    :show-inheritance:

pymcr.metrics module
--------------------

.. automodule:: pymcr.metrics
    :members:
    :undoc-members:
    :show-inheritance:

pymcr.regressors module
-----------------------

.. automodule:: pymcr.regressors
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pymcr
    :members:
    :undoc-members:
    :show-inheritance:
